Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(307)

Unified Diff: third_party/WebKit/Source/core/dom/Text.cpp

Issue 2373223002: Fieldset should allow whitespaces even though LayoutFlexibleBox doesn't. (Closed)
Patch Set: Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/LayoutTests/platform/win/fast/forms/focus-selection-textarea-expected.txt ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/dom/Text.cpp
diff --git a/third_party/WebKit/Source/core/dom/Text.cpp b/third_party/WebKit/Source/core/dom/Text.cpp
index 89d8f9b7e117e18cf10bf07a05200ee52fc68cca..7d5e50c1beaf5f0c95d8c2b804966ca16e7f5fd3 100644
--- a/third_party/WebKit/Source/core/dom/Text.cpp
+++ b/third_party/WebKit/Source/core/dom/Text.cpp
@@ -243,8 +243,9 @@ Node* Text::cloneNode(bool /*deep*/)
static inline bool canHaveWhitespaceChildren(const LayoutObject& parent)
{
- // <button> should allow whitespace even though LayoutFlexibleBox doesn't.
- if (parent.isLayoutButton())
+ // <button> and <fieldset> should allow whitespace even though
+ // LayoutFlexibleBox doesn't.
+ if (parent.isLayoutButton() || parent.isFieldset())
return true;
if (parent.isTable() || parent.isTableRow() || parent.isTableSection()
« no previous file with comments | « third_party/WebKit/LayoutTests/platform/win/fast/forms/focus-selection-textarea-expected.txt ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698